/*
Copyright (C) 2017 Belledonne Communications SARL

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef _LINPHONE_CONFERENCE_SCHEDULER_LISTENER_HH
#define _LINPHONE_CONFERENCE_SCHEDULER_LISTENER_HH

#include <list>
#include "conference_scheduler.hh"
#include "object.hh"






namespace linphone {

	class ConferenceScheduler;
	class Address;

	/**
	 *
	 */
	class ConferenceSchedulerListener: public Listener {
	
		public:


	
		public:
			
		
			/**
			 * @brief Callback for notifying when a registration state has changed for the
			 * conference scheduler. 
			 *
			 * @param state The current LinphoneConferenceSchedulerState. 
			 */
			LINPHONECXX_PUBLIC virtual void onStateChanged(const std::shared_ptr<linphone::ConferenceScheduler> & conferenceScheduler, linphone::ConferenceScheduler::State state) {};
			
			/**
			 * @brief Callback for notifying when conference invitations have been sent. 
			 *
			 * In case of error for some participants, their addresses will be given as
			 * parameter. 
			 * @param failedInvitations a list of addresses for which invitation couldn't be
			 * sent.      
			 */
			LINPHONECXX_PUBLIC virtual void onInvitationsSent(const std::shared_ptr<linphone::ConferenceScheduler> & conferenceScheduler, const std::list<std::shared_ptr<linphone::Address>> & failedInvitations) {};
			
			
	};

};

#endif // _LINPHONE_CONFERENCE_SCHEDULER_LISTENER_HH
